sfs.fd.esa
==========

.. automodule:: sfs.fd.esa

   
   
   .. rubric:: Functions

   .. autosummary::
   
      line_2d_edge
      line_2d_edge_dipole_ssd
      plane_2d_edge
      plane_2d_edge_dipole_ssd
      point_25d_edge
   
   

   
   
   

   
   
   